A module for downloading and caching lists of Nix/NixOS packages and options.

Modules

Cache and determine packages installed on legacy NixOS and with nix-env
Cache and determine packages installed on flakes enabled NixOS
Cache latest NixOS packages.json and options.json
Cache and determine packages installed with nix profile