flakespkgs

Function flakespkgs 

pub async fn flakespkgs() -> Result<String>
Gets a list of all packages in the NixOS system with their name and version. Can be used to find what versions of system packages are currently installed. Will only work on NixOS systems.