pub async fn getflakepkgs(paths: &[&str]) -> Result<HashMap<String, String>>Expand description
Returns a list of all installed system packages with their attribute and version
The input paths should be the paths to the configuration.nix files containing environment.systemPackages