Module nixos

Module nixos 

Cache latest NixOS packages.json and options.json

Functions

nixosoptions
Downloads the latest ‘options.json’ for the system from the NixOS cache and returns the path to the file. Will only work on NixOS systems.
nixospkgs
Downloads the latest packages.json for the system from the NixOS cache and returns the path to an SQLite database nixospkgs.db which contains package data. Will only work on NixOS systems.