Module profile

Module profile 

Cache and determine packages installed with nix profile

Structs

ProfilePkg
Struct containing information about a package installed with nix profile.

Functions

getprofilepkgs
Returns a list of all packages installed with nix profile with their name. Does not include individual version.
getprofilepkgs_versioned
Returns a list of all packages installed with nix profile with their name and version. Takes a bit longer than getprofilepkgs().
nixpkgslatest
Downloads a list of available package versions packages.db and returns the path to the file.
unavailablepkgs