pub fn getprofilepkgs() -> Result<HashMap<String, ProfilePkg>>Expand description
Returns a list of all packages installed with nix profile with their name.
Does not include individual version.
pub fn getprofilepkgs() -> Result<HashMap<String, ProfilePkg>>Returns a list of all packages installed with nix profile with their name.
Does not include individual version.