A module for managing the configuration containing user and system options.

Modules

Make and manage a configuration file that contains the locations of system configuration files and some user configuration.