NixDataConfig

Struct NixDataConfig 

pub struct NixDataConfig {
    pub systemconfig: Option<String>,
    pub flake: Option<String>,
    pub flakearg: Option<String>,
    pub generations: Option<u32>,
}
Struct containing locations of system configuration files and some user configuration.

Fields

systemconfig: Option<String>

Path to the NixOS configuration file. Typically /etc/nixos/configuration.nix.

flake: Option<String>

Path to the NixOS flake file. Typically /etc/nixos/flake.nix.

flakearg: Option<String>

Specifies which configuration should be user from the nixosConfigurations attribute set in the flake file. If not set, NixOS defaults to the hostname of the system.

generations: Option<u32>

Specifies how many NixOS generations to keep. If set to 0, all generations will be kept. If not set, the default is 5.