Cache and determine packages installed on legacy NixOS and with nix-env
Functions
- getenvpkgs
- Gets a list of all packages installed with
nix-envwith their name and version. Due to limitations ofnix-env, the HashMap keys are the packagespnamerather thanattributePath. This means that finding more information about the specific derivations is more difficult. - getlegacypkgs
- Gets a list of all packages in NixOS systems with their attribute and version.
The input
pathsshould be the paths to theconfiguration.nixfiles containingenvironment.systemPackages - legacypkgs
- Gets a list of all packages in legacy NixOS systems with their name and version. Can be used to find what versions of system packages are currently installed. Will only work on legacy NixOS systems.
- unavailablepkgs
- uptodate