Cache and determine packages installed on legacy NixOS and with nix-env
Functions
Gets a list of all packages installed with
nix-env with their name and version.
Due to limitations of nix-env, the HashMap keys are the packages pname rather than attributePath.
This means that finding more information about the specific derivations is more difficult.Gets a list of all packages in NixOS systems with their attribute and version.
The input
paths should be the paths to the configuration.nix files containing environment.systemPackagesGets a list of all packages in legacy NixOS systems with their name and version.
Can be used to find what versions of system packages are currently installed.
Will only work on legacy NixOS systems.