pub fn getenvpkgs() -> Result<HashMap<String, String>>
Gets a list of all packages installed with nix-env with their name and version. Due to limitations of nix-env, the HashMap keys are the packages pname rather than attributePath. This means that finding more information about the specific derivations is more difficult.