Cache and determine packages installed on flakes enabled NixOS

Functions

Gets a list of all packages in the NixOS system with their name and version. Can be used to find what versions of system packages are currently installed. Will only work on NixOS systems.
Returns a list of all installed system packages with their attribute and version The input paths should be the paths to the configuration.nix files containing environment.systemPackages