pub async fn flakespkgs() -> Result<String>Expand description
Gets a list of all packages in the NixOS system with their name and version. Can be used to find what versions of system packages are currently installed. Will only work on NixOS systems.