pub fn getflakepkgs(paths: &[&str]) -> Result<HashMap<String, String>>
Returns a list of all installed system packages with their attribute and version The input paths should be the paths to the configuration.nix files containing environment.systemPackages