Cache latest NixOS packages.json and options.json
Functions
- nixosoptions
- Downloads the latest ‘options.json’ for the system from the NixOS cache and returns the path to the file. Will only work on NixOS systems.
- nixospkgs
- Downloads the latest
packages.jsonfor the system from the NixOS cache and returns the path to an SQLite databasenixospkgs.dbwhich contains package data. Will only work on NixOS systems.