Cache latest NixOS packages.json and options.json

Functions

Downloads the latest ‘options.json’ for the system from the NixOS cache and returns the path to the file. Will only work on NixOS systems.
Downloads the latest packages.json for the system from the NixOS cache and returns the path to the file. Will only work on NixOS systems.