Cache and determine packages installed with nix profile

Structs

Struct containing information about a package installed with nix profile.

Functions

Returns a list of all packages installed with nix profile with their name. Does not include individual version.
Returns a list of all packages installed with nix profile with their name and version. Takes significantly longer than getprofilepkgs().
Downloads the latest packages.json from nixpkgs-unstable and returns the path to the file.