Struct nix_data::config::configfile::NixDataConfig
source · [−]pub struct NixDataConfig {
pub systemconfig: Option<String>,
pub flake: Option<String>,
pub flakearg: Option<String>,
pub userpkgtype: Option<UserPkgType>,
}Expand description
Struct containing locations of system configuration files and some user configuration.
Fields
systemconfig: Option<String>Path to the NixOS configuration file. Typically /etc/nixos/configuration.nix.
flake: Option<String>Path to the NixOS flake file. Typically /etc/nixos/flake.nix.
flakearg: Option<String>Specifies which configuration should be user from the nixosConfigurations attribute set in the flake file.
If not set, NixOS defaults to the hostname of the system.
userpkgtype: Option<UserPkgType>Type of package manager used by the user.